@@ -15,17 +15,16 @@
 #
 
 import warnings
-from datetime import timedelta
 from http import HTTPStatus
 from typing import Optional, Union
 
 import requests
-import requests_cache
 
-from pysisu.formats import LatestAnalysisResultsFormats, Table
-from pysisu.latest_analysis_result import to_table
-from pysisu.proto.sisu.v1.api import (
+from .formats import LatestAnalysisResultsFormats, Table
+from .latest_analysis_result import to_table
+from .proto.sisu.v1.api import (
     AnalysesListResponse,
+    AnalysisRequest,
     AnalysisRunResultsResponse,
     CreateDataSetRequestDataset,
     DataSetsResponse,
@@ -36,10 +35,12 @@ from pysisu.proto.sisu.v1.api import (
     GetProjectsListResponseListProjectResponse,
     GetSegmentDataResponse,
     MetricsListResponse,
+    ModifyAnalysisResponse,
     SetAnalysisFiltersRequest,
+    AnalysisDimensionsListResponse,
 )
-from pysisu.query_helpers import build_url, pathjoin, semver_parse
-from pysisu.version import __version__ as PYSISU_VERSION
+from .query_helpers import build_url, pathjoin, semver_parse
+from .version import __version__ as PYSISU_VERSION
 
 
 class PySisuBaseException(Exception):
@@ -67,11 +68,6 @@ class PySisu:
     _api_key: str
 
     def __init__(self, api_key: str, url: str = "https://vip.sisu.ai") -> None:
-        self.session = requests_cache.CachedSession(
-            cache_name="pysisu_cache",
-            use_cache_dir=True,
-            expire_after=timedelta(days=1),
-        )
         self._check_compatibility()
         self._url = url
         self._api_key = api_key
@@ -134,12 +130,9 @@ class PySisu:
             "Authorization": self._api_key,
             "User-Agent": f"PySisu/{PYSISU_VERSION}",
         }
-        # don't cache API responses, we don't want to return stale responses
-        # or cache in-flight status
-        with self.session.cache_disabled():
-            r = self.session.request(
-                request_method, url_path, headers=headers, json=json
-            )
+        r = requests.request(
+            request_method, url_path, headers=headers, json=json
+        )
         if r.status_code != HTTPStatus.OK:
             raise PySisuInvalidResponseFromServer(
                 "Result did not complete", r.content
@@ -147,7 +140,7 @@ class PySisu:
         return r.json()
 
     def _check_compatibility(self):
-        r = self.session.get("https://pypi.python.org/pypi/pysisu/json")
+        r = requests.get("https://pypi.python.org/pypi/pysisu/json")
         try:
             latest_version = r.json()["info"]["version"]
         except (requests.RequestException, KeyError):
@@ -296,3 +289,21 @@ class PySisu:
         return GetProjectsAnalysesListResponse().from_dict(
             self._call_sisu_api(url_path, request_method="GET")
         )
+
+    def modify_analysis(
+        self,
+        project_id: int,
+        analysis_id: int,
+        modify_analysis_req: AnalysisRequest,
+    ) -> ModifyAnalysisResponse:
+        path = [f"api/v1/projects/{project_id}/analyses/{analysis_id}"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return ModifyAnalysisResponse().from_dict(
+            self._call_sisu_api(url_path, request_method="PATCH", json=modify_analysis_req.to_json()))
+
+    def get_analysis_dimensions_list(self, analysis_id) -> AnalysisDimensionsListResponse:
+        path = [f"api/v1/analyses/{analysis_id}/dimensions"]
+        url_path = build_url(self._url, pathjoin(*path), {})
+        return AnalysisDimensionsListResponse().from_dict(
+            self._call_sisu_api(url_path, request_method="GET")
+        )
